Destral testing library
=======================

A library to do tests with our OpenERP Server

.. note::
  The API is not stable, and can be changed.

.. epigraph::

   Code as if the next guy to maintain your code is a homicidal maniac who knows where you live.

   -- Kathy Sierra and Bert Bates
